@@ -22,7 +22,7 @@
 #include <stddef.h>
 
 #include <efivar.h>
-#include "endian.h"
+#include "efivar_endian.h"
 #include "dp.h"
 
 static ssize_t
@@ -408,6 +408,7 @@ _format_message_dn(char *buf, size_t size, const_efidp dp)
 						- sizeof (efidp_header)
 						- sizeof (efi_guid_t));
 		}
+		off += format(buf, size, off, ")");
 		break;
 			       }
 	case EFIDP_MSG_IPv6: {
