@@ -43,17 +43,26 @@ efi_guid_to_str(const efi_guid_t *guid, char **sp)
 
 	if (!sp) {
 		return snprintf(NULL, 0, GUID_FORMAT,
-				guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 				guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 				guid->e[4], guid->e[5]);
 	} else if (sp && *sp) {
 		return snprintf(*sp, GUID_LENGTH_WITH_NUL, GUID_FORMAT,
-				guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 				guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 				guid->e[4], guid->e[5]);
 	} else {
 		rc = asprintf(&ret, GUID_FORMAT,
-				guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 				guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 				guid->e[4], guid->e[5]);
 		if (rc >= 0)
@@ -62,8 +71,14 @@ efi_guid_to_str(const efi_guid_t *guid, char **sp)
 	return rc;
 }
 
-extern struct guidname efi_well_known_guids[], efi_well_known_names[];
-extern char efi_well_known_guids_end, efi_well_known_names_end;
+extern struct guidname efi_well_known_guids
+	__attribute__((__visibility__ ("default")));
+extern struct guidname efi_well_known_names
+	__attribute__((__visibility__ ("default")));
+extern struct guidname efi_well_known_guids_end
+	__attribute__((__visibility__ ("default")));
+extern struct guidname efi_well_known_names_end
+	__attribute__((__visibility__ ("default")));
 
 static int
 __attribute__((__nonnull__ (1, 2)))
@@ -91,15 +106,15 @@ _get_common_guidname(const efi_guid_t *guid, struct guidname **result)
 {
 	intptr_t end = (intptr_t)&efi_well_known_guids_end;
 	intptr_t start = (intptr_t)&efi_well_known_guids;
-	size_t nmemb = (end - start) / sizeof (efi_well_known_guids[0]);
+	size_t nmemb = (end - start) / sizeof (efi_well_known_guids);
 
 	struct guidname key;
 	memset(&key, '\0', sizeof (key));
 	memcpy(&key.guid, guid, sizeof (*guid));
 
 	struct guidname *tmp;
-	tmp = bsearch(&key, efi_well_known_guids, nmemb,
-			sizeof (efi_well_known_guids[0]), cmpguidp);
+	tmp = bsearch(&key, &efi_well_known_guids, nmemb,
+			sizeof (efi_well_known_guids), cmpguidp);
 	if (!tmp) {
 		*result = NULL;
 		errno = ENOENT;
@@ -166,17 +181,26 @@ efi_guid_to_id_guid(const efi_guid_t *guid, char **sp)
 	}
 	if (!sp) {
 		return snprintf(NULL, 0, "{"GUID_FORMAT"}",
-				guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 				guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 				guid->e[4], guid->e[5]);
 	} else if (sp && *sp) {
 		return snprintf(*sp, GUID_LENGTH_WITH_NUL+2, "{"GUID_FORMAT"}",
-				guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 				guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 				guid->e[4], guid->e[5]);
 	}
 	rc = asprintf(&ret, "{"GUID_FORMAT"}",
-			guid->a, guid->b, guid->c, bswap_16(guid->d),
+				le32_to_cpu(guid->a),
+				le16_to_cpu(guid->b),
+				le16_to_cpu(guid->c),
+				be16_to_cpu(guid->d),
 			guid->e[0], guid->e[1], guid->e[2], guid->e[3],
 			guid->e[4], guid->e[5]);
 	if (rc >= 0)
@@ -209,12 +233,9 @@ efi_name_to_guid(const char *name, efi_guid_t *guid)
 {
 	intptr_t end = (intptr_t)&efi_well_known_names_end;
 	intptr_t start = (intptr_t)&efi_well_known_names;
-	size_t nmemb = (end - start) / sizeof (efi_well_known_names[0]);
+	size_t nmemb = (end - start) / sizeof (efi_well_known_names);
 	size_t namelen;
 
-	if (!name || !guid)
-		return -1;
-
 	namelen = strnlen(name, 39);
 	struct guidname key;
 	memset(&key, '\0', sizeof (key));
@@ -229,8 +250,8 @@ efi_name_to_guid(const char *name, efi_guid_t *guid)
 	key.name[sizeof(key.name) - 1] = '\0';
 
 	struct guidname *result;
-	result = bsearch(&key, efi_well_known_names, nmemb,
-			sizeof (efi_well_known_names[0]), cmpnamep);
+	result = bsearch(&key, &efi_well_known_names, nmemb,
+			sizeof (efi_well_known_names), cmpnamep);
 	if (result != NULL) {
 		memcpy(guid, &result->guid, sizeof (*guid));
 		return 0;
