@@ -59,7 +59,7 @@ set_disk_and_part_name(struct disk_info *info)
 	char *linkbuf;
 	ssize_t rc;
 
-	rc = sysfs_readlink(&linkbuf, "/sys/dev/block/%"PRIu64":%hhd",
+	rc = sysfs_readlink(&linkbuf, "/sys/dev/block/%"PRIu64":%hhu",
 		      info->major, info->minor);
 	if (rc < 0)
 		return -1;
@@ -81,6 +81,10 @@ set_disk_and_part_name(struct disk_info *info)
 	}
 	penultimate++;
 
+	/*
+	 * If there's a better way to figure this out, it'd be good, because
+	 * I don't want to have to change this for every new disk type...
+	 */
 	if (!strcmp(penultimate, "block")) {
 		if (!info->disk_name) {
 			info->disk_name = strdup(ultimate);
@@ -93,6 +97,18 @@ set_disk_and_part_name(struct disk_info *info)
 			if (rc < 0)
 				return -1;
 		}
+	} else if (!strncmp(penultimate, "nvme", 4)) {
+		if (!info->disk_name) {
+			info->disk_name = strdup(ultimate);
+			if (!info->disk_name)
+				return -1;
+		}
+		if (!info->part_name) {
+			rc = asprintf(&info->part_name, "%sp%d",
+				      info->disk_name, info->part);
+			if (rc < 0)
+				return -1;
+		}
 	} else {
 		if (!info->disk_name) {
 			info->disk_name = strdup(penultimate);
@@ -117,7 +133,7 @@ get_partition_number(const char *devpath)
 	int rc;
 	unsigned int maj, min;
 	char *linkbuf;
-	char *partbuf;
+	uint8_t *partbuf;
 	int ret = -1;
 
 	rc = stat(devpath, &statbuf);
@@ -129,8 +145,8 @@ get_partition_number(const char *devpath)
 		return -1;
 	}
 
-	maj = gnu_dev_major(statbuf.st_rdev);
-	min = gnu_dev_minor(statbuf.st_rdev);
+	maj = major(statbuf.st_rdev);
+	min = minor(statbuf.st_rdev);
 
 	rc = sysfs_readlink(&linkbuf, "/sys/dev/block/%u:%u", maj, min);
 	if (rc < 0)
@@ -140,7 +156,7 @@ get_partition_number(const char *devpath)
 	if (rc < 0)
 		return -1;
 
-	rc = sscanf(partbuf, "%d\n", &ret);
+	rc = sscanf((char *)partbuf, "%d\n", &ret);
 	if (rc != 1)
 		return -1;
 	return ret;
@@ -185,7 +201,6 @@ sysfs_sata_get_port_info(uint32_t print_id, struct disk_info *info)
 {
 	DIR *d;
 	struct dirent *de;
-	int saved_errno;
 	uint8_t *buf = NULL;
 	int rc;
 
@@ -204,19 +219,18 @@ sysfs_sata_get_port_info(uint32_t print_id, struct disk_info *info)
 		int rc;
 		rc = sscanf(de->d_name, "dev%d.%d.%d", &found_print_id,
 			    &found_pmp, &found_devno);
-		if (rc == 2) {
-			found_devno = found_pmp;
-			found_pmp=0;
-		} else if (rc != 3) {
-			saved_errno = errno;
-			closedir(d);
-			errno = saved_errno;
-			return -1;
-		}
-		if (found_print_id == print_id) {
-			info->sata_info.ata_devno = found_devno;
+		if (rc == 3) {
+			info->sata_info.ata_devno = 0;
 			info->sata_info.ata_pmp = found_pmp;
 			break;
+		} else if (rc == 2) {
+			info->sata_info.ata_devno = 0;
+			info->sata_info.ata_pmp = 0x8000;
+			break;
+		} else {
+			closedir(d);
+			errno = EINVAL;
+			return -1;
 		}
 	}
 	closedir(d);
@@ -230,7 +244,6 @@ sysfs_sata_get_port_info(uint32_t print_id, struct disk_info *info)
 	if (rc != 1)
 		return -1;
 
-	info->sata_info.ata_port -= 1;
 	return 0;
 }
 
@@ -340,7 +353,7 @@ sysfs_parse_sas(uint8_t *buf, ssize_t size, ssize_t *off,
 {
 	int rc;
 	int psz = 0;
-	char *filebuf = NULL;
+	uint8_t *filebuf = NULL;
 	uint64_t sas_address;
 
 	*poff = 0;
@@ -434,7 +447,7 @@ sysfs_parse_sas(uint8_t *buf, ssize_t size, ssize_t *off,
 	if (rc < 0)
 		return -1;
 
-	rc = sscanf(filebuf, "%"PRIx64, &sas_address);
+	rc = sscanf((char *)filebuf, "%"PRIx64, &sas_address);
 	if (rc != 1)
 		return -1;
 
@@ -477,7 +490,7 @@ make_pci_path(uint8_t *buf, ssize_t size, char *pathstr, ssize_t *pathoff)
 		return -1;
 	poff += psz;
 
-	char *fbuf = NULL;
+	uint8_t *fbuf = NULL;
 	rc = read_sysfs_file(&fbuf,
 			     "/sys/devices/pci%04x:%02x/firmware_node/hid",
 			     root_domain, root_bus);
@@ -847,12 +860,13 @@ ssize_t
 __attribute__((__visibility__ ("hidden")))
 make_mac_path(uint8_t *buf, ssize_t size, const char * const ifname)
 {
-	struct ifreq ifr = { 0, };
+	struct ifreq ifr;
 	struct ethtool_drvinfo drvinfo = { 0, };
 	int fd, rc;
 	ssize_t ret = -1, sz, off=0;
 	char busname[PATH_MAX+1] = "";
 
+	memset(&ifr, 0, sizeof (ifr));
 	strncpy(ifr.ifr_name, ifname, IF_NAMESIZE);
 	drvinfo.cmd = ETHTOOL_GDRVINFO;
 	ifr.ifr_data = (caddr_t)&drvinfo;
